#
# spec file for package funkload
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pkgname FunkLoad
Name:           funkload
Version:        1.17.1
Release:        lp150.1.3
Summary:        Functional and Load Web Tester
License:        GPL-2.0
Group:          Productivity/Networking/Web/Utilities
Url:            http://funkload.nuxeo.org/
Source:         https://github.com/nuxeo/FunkLoad/archive/%{version}/FunkLoad-%{version}.tar.gz
Source99:       funkload-rpmlintrc
# pbleser: remove shebangs from non-executable scripts
Patch1:         funkload-remove_shebang.patch
BuildRequires:  python-devel
BuildRequires:  python-setuptools

Recommends:     python-docutils
Recommends:     python-webunit
Recommends:     gnuplot
Recommends:     tcpwatch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%py_requires
# sle 11 is bOrken
%if %{suse_version} != 1110
BuildArch:      noarch
%endif

%description
FunkLoad is a functional and load Web tester whose main use cases are
functional testing of Web projects (and thus regression testing as well),
performance testing, load testing (such as volume testing or longevity
testing), and stress testing. It can also be used to write Web agents to script
any Web repetitive task, like checking whether a site is alive.

%prep
%setup -q -n %{pkgname}-%{version}
%patch1

%build
sed -i '/ez_/d' setup.py
python setup.py build

%install
python setup.py install \
    --prefix="%{_prefix}" \
    --root=%{buildroot} \
    --record-rpm=files.lst

rm -rf "%{buildroot}%{python_sitelib}/funkload/demo"
perl -n -i -e 'print unless m|^(%dir\s+)?%{python_sitelib}/funkload/demo|' files.lst

%files -f files.lst
%defattr(-,root,root)
%doc CHANGES.txt LICENSE.txt README.txt THANKS TODO.txt

%changelog
* Fri Jun  5 2015 boris@steki.net
- replaced source archive location from pypi to github as package contain
  documentation which pypi version does not have.
- updated to release 1.17.1
  * Add a discover mode to the bench runner, so fl-run-bench can be
    invoked without specifying the particular test case. This implementation
    attempts to behave like unittest’s ‘discover’ argument, and there is
    even a similar –failfast option.
  * Support https proxy (http proxy was already supported)
  * Add a midCycle hook to execute an action in the middle of a cycle
  * Add -L options to fl-record to enable tcpwatch forwarded mode which
    is usefull if you have an http_proxy to pass.
  * Add –quiet option to fl-build-report to remove warning in rst to html convertion
  * GH-71: zeromq-based publisher that will let each node
    publish in realtime the tests results
  * GH-68: Use lightweight threads (greenlets) if available.
  * Added one more RPS chart in Section 5, where the X-axis
    represents time(in second) and the Y-axis represents RPS.
  * Added support for providing the test configuration file with –config
  * Display the description in the URL when rendering the page in Firefox
  * GH-41: Allow fl-run-bench to take modules in addition to filenames
  * Support for gzip compression
  * Experimental comet request support, handle stream request in a separate thread
  * Ability to configure multiple benchers per server in distribute mode
  * Ability to configure multiple monitors per server (useful if you have
    to use ssh tunnels instead of read hostnames).
* Wed Apr  8 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
- Cleanup dependencies`
* Sun Sep  4 2011 pascal.bleser@opensuse.org
- update to 1.16.1:
  * fixes distributed code
- changes from 1.16.0:
  * extends HTTP methods with HEAD and OPTIONS, enable to send any methods
    using the new "method" API, adding PROPFIND DAV example
  * GH-9: new options for distributed mode: you can specify the Python binary
    to use with ``--distribute-python=PYTHON_BIN`` option and additional
    packages to install on slaves with the
    ``--distributed-packages=DISTRIBUTED_PACKAGES`` option
  * GH-9: added the ability to monitor hosts from the central host; the
    monitoring will also retroactively match up the concurrent users for
    graphing purposes
  * GH-5: ``fl-record`` now checks for ``tcpwatch`` command in addition to
    ``tcpwatch.py`` and ``tcpwatch-httpproxy``
  * GH-6: filter out .swfs when building funkload tests with ``fl-record``
  * GH-10: support of python2.7
  * GH-15: exposed the load_auto_links parameter to the get/put/post/method
    methods so that the option to not parse the payload is available when
    writing a test
  * fix org-mode output for Org 7.5, adding missing monitoring section
  * GH-14: fix report creation when having error message with non-us characters
  * GH-11: handling of deleted cookies
  * GH-7: data and demo directory missing
- changes from 1.15.0:
  * now supporting emacs Org-mode_ text format as report output; this enables
    to edit a report as plain text and to produce professional PDF reports
    througth the Org-mode_ LaTeX export
  * new `trend report to display evolution of performances over time; just use
    the ``--trend`` option of the ``fl-build-report`` command
  * the credential server can serve a sequence; using ``xmlrpc_get_seq``
    threads can share a sequence
  * removing deprecated gdchart support, now relying only on gnuplot; note that
    a mathplotlib support is on the TODO list
* Wed Feb 16 2011 pascal.bleser@opensuse.org
- initial version (1.14.0)
